@@ -42,22 +42,15 @@
 		in-reply-to
 		(and vm-in-reply-to-format
 		     (let ((vm-summary-uninteresting-senders nil))
-		       (vm-sprintf 'vm-in-reply-to-format (car mp))))
+		       (vm-summary-sprintf vm-in-reply-to-format (car mp))))
 		in-reply-to (and (not (equal "" in-reply-to)) in-reply-to))
 	  (and subject (stringp vm-reply-subject-prefix)
 	       (let ((case-fold-search t))
-		 (and
 		  (not
 		   (equal
 		    (string-match (regexp-quote vm-reply-subject-prefix)
 				  subject)
-		    0))
-		  (or
-		   (not (stringp vm-subject-ignored-prefix))
-		   (not
-		    (equal
-		     (string-match vm-subject-ignored-prefix subject)
-		     0)))))
+		    0)))
 	       (setq subject (concat vm-reply-subject-prefix subject))))
 	 (t (cond ((setq tmp (vm-get-header-contents (car mp) "Reply-To:"
 						     ", "))
@@ -84,11 +77,10 @@
 		      (setq cc (concat cc "," tmp2))
 		    (setq cc tmp2)))))
 	(setq references
-	      (cons (vm-get-header-contents (car mp) "References:" " ")
-		    (cons (vm-get-header-contents (car mp) "In-reply-to:" " ")
-			  (cons (vm-get-header-contents (car mp) "Message-ID:"
-							" ")
-				references))))
+	      (cons (or (vm-get-header-contents (car mp) "References:" " ")
+			(vm-get-header-contents (car mp) "In-reply-to:" " "))
+		    (cons (vm-get-header-contents (car mp) "Message-ID:" " ")
+			  references)))
 	(setq newsgroups
 	      (cons (or (and to-all (vm-get-header-contents (car mp) "Followup-To:" ","))
 			(vm-get-header-contents (car mp) "Newsgroups:" ","))
@@ -177,7 +169,8 @@
 	(delete-char 1))
     (if vm-included-text-attribution-format
 	(let ((vm-summary-uninteresting-senders nil))
-	  (insert (vm-sprintf 'vm-included-text-attribution-format message))))
+	  (insert (vm-summary-sprintf vm-included-text-attribution-format
+				      message))))
     ; turn off zmacs-regions for Lucid Emacs 19
     ; and get around transient-mark-mode in FSF Emacs 19
     ; all this so that (mark) does what it did in v18, sheesh.
@@ -354,6 +347,10 @@ vm-included-text-prefix is prepended to every yanked line."
 as having been replied to, if appropriate."
   (interactive "P")
   (vm-check-for-killed-folder)
+  (if (and (boundp 'mail-alias-file)
+	   mail-alias-file
+	   (not (eq (user-uid) 0)))
+      (error "Must be superuser to use mail-alias-file.  Please set mail-alias-file to nil."))
   (let ((b (current-buffer)))
     (vm-mail-send)
     (cond ((null (buffer-name b)) ;; dead buffer
@@ -408,8 +405,7 @@ as having been replied to, if appropriate."
       nil
     (save-restriction
       (save-excursion
-	(let ((resent nil)
-	      (time (current-time)))
+	(let ((resent nil))
 	  (if (or (vm-mail-mode-get-header-contents "Resent-To:")
 		  (vm-mail-mode-get-header-contents "Resent-Cc:")
 		  (vm-mail-mode-get-header-contents "Resent-Bcc:"))
@@ -419,11 +415,9 @@ as having been replied to, if appropriate."
 	    (vm-mail-mode-remove-header "Message-ID:"))
 	  (widen)
 	  (goto-char (point-min))
-	  (insert (format "%sMessage-ID: <%d.%d.%d.%d@%s>\n"
+	  (insert (format "%sMessage-ID: %s\n"
 			  (if resent "Resent-" "")
-			  (car time) (nth 1 time) (nth 2 time)
-			  (random 1000000)
-			  (system-name))))))))
+			  (vm-make-message-id))))))))
 
 (defun vm-mail-mode-insert-date-maybe ()
   (if (not vm-mail-header-insert-date)
@@ -445,13 +439,21 @@ as having been replied to, if appropriate."
 	  (widen)
 	  (goto-char (point-min))
 	  (insert (format "%sDate: " (if resent "Resent-" ""))
-		  (format-time-string "%a, " time)
+		  (capitalize
+		   (car (nth (string-to-int (format-time-string "%w" time))
+			     vm-weekday-alist)))
+		  ", "
 		  ;; %e generated " 2".  Go from string to int
 		  ;; to string to get rid of the blank.
 		  (int-to-string
 		   (string-to-int
 		    (format-time-string "%e" time)))
-		  (format-time-string " %b %Y %H:%M:%S" time)
+		  " "
+		  (capitalize
+		   (car (nth
+			 (1- (string-to-int (format-time-string "%m" time)))
+			 vm-month-alist)))
+		  (format-time-string " %Y %H:%M:%S" time)
 		  (format " %s%02d%02d"
 			  (if (< timezone 0) "-" "+")
 			  (abs hour)
@@ -492,6 +494,7 @@ as replied to, forwarded, etc, if appropriate."
     (if (and vm-confirm-mail-send
 	     (not (y-or-n-p "Send the message? ")))
 	(error "Message not sent.")))
+  (save-excursion (run-hooks 'vm-mail-send-hook))
   (vm-mail-mode-insert-date-maybe)
   (vm-mail-mode-insert-message-id-maybe)
   ;; send mail using MIME if user requests it and if the buffer
@@ -744,7 +747,8 @@ Subject: header manually."
 	 nil
 	 (and vm-forwarding-subject-format
 	      (let ((vm-summary-uninteresting-senders nil))
-		(vm-sprintf 'vm-forwarding-subject-format (car mp)))))
+		(vm-summary-sprintf vm-forwarding-subject-format
+				    (car mp)))))
 	(make-local-variable 'vm-forward-list)
 	(setq vm-system-state 'forwarding
 	      vm-forward-list (list (car mp))
@@ -1019,7 +1023,8 @@ only marked messages will be put into the digest."
 		  (mail-text)))
 	    (while mp
 	      (let ((vm-summary-uninteresting-senders nil))
-		(insert (vm-sprintf 'vm-digest-preamble-format (car mp)) "\n"))
+		(insert (vm-summary-sprintf vm-digest-preamble-format
+					    (car mp)) "\n"))
 	      (if vm-digest-center-preamble
 		  (progn
 		    (forward-char -1)
@@ -1098,6 +1103,7 @@ found, the current buffer remains selected."
 (defvar mail-aliases)
 (defvar mail-default-reply-to)
 (defvar mail-signature-file)
+(defvar mail-personal-alias-file)
 
 (defun vm-mail-internal
     (&optional buffer-name to subject in-reply-to cc references newsgroups)
@@ -1394,9 +1400,9 @@ message."
 	       (vm-mime-encode-composition))
 	  (vm-remove-mail-mode-header-separator)
 	  (goto-char (point-min))
-	  (insert (vm-leading-message-separator 'From_))
+	  (insert (vm-leading-message-separator vm-default-From_-folder-type))
 	  (goto-char (point-max))
-	  (insert (vm-trailing-message-separator 'From_))
+	  (insert (vm-trailing-message-separator vm-default-From_-folder-type))
 	  (set-buffer-modified-p nil)
 	  ;; point of no return, don't kill it if the user quits
 	  (setq temp-buffer nil)
@@ -1427,6 +1433,7 @@ message."
 		        switch-function yank-action
 			send-actions)
   (interactive)
+  (vm-session-initialization)
   (if continue
       (vm-continue-composing-message)
     (let ((buffer (vm-mail-internal
