@@ -455,7 +455,8 @@ folder in the order in which the messages arrived."
 	  (let ((date1 (get (car list1) 'oldest-date))
 		(date2 (get (car list2) 'oldest-date)))
 	    (cond ((string-lessp date1 date2) t)
-		  ((string-equal date1 date2) '=)
+		  ((string-equal date1 date2)
+		   (string-lessp (car list1) (car list2)))
 		  (t nil)))
 	(while (and list1 list2)
 	  (cond ((string-lessp (car list1) (car list2)) (throw 'done t))
